@@ -3,19 +3,13 @@ from ...util import _convert_quarterly_minutes
 from datetime import datetime
 import logging
 from enum import Enum
+from ...models.phases import Phases
 from ...models.const import (
     CURRENTS_ONEPHASE_1_16, CURRENTS_THREEPHASE_1_16
 )
 
 _LOGGER = logging.getLogger(__name__)
 
-
-class Phases(Enum):
-    OnePhase = "1-phase"
-    ThreePhase = "3-phase"
-    Unknown = "Unknown"
-
-
 CURRENT_DICT = {
     Phases.OnePhase: CURRENTS_ONEPHASE_1_16,
     Phases.ThreePhase: CURRENTS_THREEPHASE_1_16,
